@@ -41,7 +41,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "tandem.h"
 
 int main(int argc, char **argv)
-{ SOAP_SOCKET m, s; /* master and slave sockets */
+{ SOAP_SOCKET m, s; /* master and accepting sockets */
   struct soap soap;
   if (argc < 2)
   { fprintf(stderr, "Missing tcpip process and port\n");
@@ -61,7 +61,7 @@ int main(int argc, char **argv)
   fprintf(stderr, "Socket connection successful: master socket = %d\n", m);
   for ( ; ; )
   { s = soap_accept(&soap);
-    fprintf(stderr, "Socket connection successful: slave socket = %d\n", s);
+    fprintf(stderr, "Socket connection successful: socket = %d\n", s);
     if (s == -1)
     { soap_print_fault(&soap, stderr);
       break;
