@@ -8,6 +8,7 @@
 	$ cc -o calcserver calcserver.c stdsoap2.c soapC.c soapServer.c
 	where stdsoap2.c is in the 'gsoap' directory, or use libgsoap:
 	$ cc -o calcserver calcserver.c soapC.c soapServer.c -lgsoap
+        $ ./calcserver 8080
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
@@ -59,7 +60,7 @@ int main(int argc, char **argv)
     for ( ; ; )
     {
       s = soap_accept(&soap);
-      fprintf(stderr, "Socket connection successful: slave socket = %d\n", s);
+      fprintf(stderr, "Socket connection successful: socket = %d\n", s);
       if (!soap_valid_socket(s))
       {
         soap_print_fault(&soap, stderr);
