@@ -12,12 +12,14 @@
 	  json.c
 
 	Compile:
-	soapcpp2 -c -CSL xml-rpc.h
-	cc curl-json-currentTime.c xml-rpc.c json.c stdsoap2.c soapC.c plugin/curlapi.c -lcurl
+	$ soapcpp2 -c -CSL xml-rpc.h
+	$ cc curl-json-currentTime.c xml-rpc.c json.c stdsoap2.c soapC.c plugin/curlapi.c -lcurl
+        $ ./json-currentTimeServer 8080 & # see samples/xml-rpc-json/json-currentTimeServer.c
+        $ ./curl-json-currentTime
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2001-2017, Robert van Engelen, Genivia, Inc. All Rights Reserved.
+Copyright (C) 2001-2024, Robert van Engelen, Genivia, Inc. All Rights Reserved.
 This software is released under one of the following two licenses:
 GPL.
 --------------------------------------------------------------------------------
@@ -46,6 +48,8 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "json.h"
 #include "curlapi.h"
 
+const char server[] = "http://localhost:8080";
+
 int main()
 {
   struct soap *ctx = soap_new1(SOAP_C_UTFSTRING | SOAP_XML_INDENT);
@@ -60,7 +64,7 @@ int main()
 
   /* make the JSON REST POST request and get response */
   *string_of(request) = "getCurrentTime";
-  if (json_call(ctx, "http://www.cs.fsu.edu/~engelen/currentTimeJSON.cgi", request, &response))
+  if (json_call(ctx, server, request, &response))
   {
     soap_curl_reset(ctx);
     soap_print_fault(ctx, stderr);
