@@ -8,6 +8,8 @@
 	$ cc -Iplugin -I. -o curlclient curlclient.c stdsoap2.c soapC.c soapClient.c plugin/curlapi.c -lcurl
 	where stdsoap2.c is in the 'gsoap' directory, or use libgsoap:
 	$ cc -Iplugin -I. -o curlclient curlclient.c soapC.c soapClient.c plugin/curlapi.c -lcurl -lgsoap
+        $ ./webserver 8080 & # see samples/webserver or start ./calcserver 8080 in samples/calc
+        $ ./curlclient add 2 3
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
@@ -41,8 +43,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "calc.nsmap"
 #include "curlapi.h"
 
-const char server[] = "http://websrv.cs.fsu.edu/~engelen/calcserver.cgi";
-/* = "http://localhost:8080"; to test against samples/webserver */
+const char server[] = "http://localhost:8080";
 
 int main(int argc, char **argv)
 { struct soap soap;
