@@ -11,14 +11,16 @@
 	including the domcpp tool that was used to generate the XPath code in
 	this exampple.
 
-	soapcpp2 -Iimport dom2calc.h
-	cc -o dom2calc dom2calc.cpp stdsoap2.cpp soapC.cpp dom.cpp
+	$ soapcpp2 -Iimport dom2calc.h
+	$ cc -o dom2calc dom2calc.cpp stdsoap2.cpp soapC.cpp dom.cpp
+        $ ./calcserver 8080 & # see samples/calc++
+        $ ./domc2calc
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2000-2016, Robert van Engelen, Genivia, Inc. All Rights Reserved.
+Copyright (C) 2000-2024, Robert van Engelen, Genivia, Inc. All Rights Reserved.
 This software is released under one of the following two licenses:
-GPL or Genivia's license for commercial use.
+GPL.
 --------------------------------------------------------------------------------
 GPL license.
 
@@ -44,7 +46,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 #include "soapH.h"
 
-const char server[] = "http://websrv.cs.fsu.edu/~engelen/calcserver.cgi";
+const char server[] = "http://localhost:8080";
 
 // copied and modified from:
 // domcpp -M -n -rrequest calc.add.req.xml
