@@ -3,9 +3,12 @@
 
 	LU factorization Web service.
 
+        $ ./luserver 8080 &
+        $ ./luclient
+
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2001-2008, Robert van Engelen, Genivia, Inc. All Rights Reserved.
+Copyright (C) 2001-2024, Robert van Engelen, Genivia, Inc. All Rights Reserved.
 This software is released under one of the following two licenses:
 GPL.
 --------------------------------------------------------------------------------
