@@ -3,23 +3,24 @@
 	
 	Polymorphic object exchange example.
 
-	This application is both a client and CGI-based server to demonstrate
+	This application is both a client and server to demonstrate
 	object exchange (derived types + overriding)
 
-	Server: install as CGI.
+	Server:
+        $ ./polytest
 
 	Client: invoke from the command line, for example:
 	
-	$ polytest.cgi o
-	$ polytest.cgi s
-	$ polytest.cgi q
-	$ polytest.cgi l
+	$ ./polytest o
+	$ ./polytest s
+	$ ./polytest q
+	$ ./polytest l
 
 	Modify the server string below to target your server URL endpoint.
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2001-2008, Robert van Engelen, Genivia, Inc. All Rights Reserved.
+Copyright (C) 2001-2024, Robert van Engelen, Genivia, Inc. All Rights Reserved.
 This software is released under one of the following two licenses:
 GPL.
 --------------------------------------------------------------------------------
@@ -46,42 +47,70 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 */
 
 #include "soapH.h"
+#include "polymorph.nsmap"
 
-const char *server = "http://www.cs.fsu.edu/~engelen/polytest2.cgi";
+const char *server = "http://localhost:8080";
 
 using namespace std;
 
 int main(int argc, char **argv)
-{ struct soap soap;
+{
+  struct soap soap;
   ns__polytestResponse r;
   soap_init(&soap);
   if (argc <= 1)
-    soap_serve(&soap); // if no args, act as a CGI Web service
+  {
+#if 0
+    soap_serve(&soap); // to run as a (Fast)CGI Web service
+#else
+    SOAP_SOCKET m = soap_bind(&soap, NULL, 8080, 1);
+    if (soap_valid_socket(m))
+    {
+      while (true)
+      {
+        SOAP_SOCKET s = soap_accept(&soap);
+        if (!soap_valid_socket(s))
+          break;
+        soap_serve(&soap);
+        soap_destroy(&soap);
+        soap_end(&soap);
+      }
+    }
+    soap_print_fault(&soap, stderr);
+    soap_free(&soap);
+#endif
+  }
   else
-  { switch (*argv[1])
-    { case 'o':
-      { ns__Object o("SOAP");
+  {
+    switch (*argv[1])
+    {
+      case 'o':
+      {
+        ns__Object o("SOAP");
         cout << "Sending: ";
 	o.print();
         soap_call_ns__polytest(&soap, server, "", &o, r);
         break;
       }
       case 's':
-      { ns__Shape s("Triangle", 3);
+      {
+        ns__Shape s("Triangle", 3);
         cout << "Sending: ";
 	s.print();
         soap_call_ns__polytest(&soap, server, "", &s, r);
         break;
       }
       case 'q':
-      { ns__Shape q("Cubicle", 2);
+      {
+        ns__Shape q("Cubicle", 2);
         cout << "Sending: ";
 	q.print();
         soap_call_ns__polytest(&soap, server, "", &q, r);
         break;
       }
       case 'l':
-      { ns__List l(4);
+      {
+        ns__List l(4);
 	l[0] = new ns__Object("SOAP");
 	l[1] = new ns__Shape("Triangle", 3);
 	l[2] = new ns__Square("Cubicle", 2);
@@ -100,7 +129,8 @@ int main(int argc, char **argv)
     if (soap.error)
       soap_print_fault(&soap, stderr);
     else
-    { cout << "Received: ";
+    {
+      cout << "Received: ";
       r.out->print();
     }
   }
@@ -108,11 +138,13 @@ int main(int argc, char **argv)
 }
 
 ns__Object::ns__Object()
-{ name = (char*)"Object";
+{
+  name = (char*)"Object";
 }
 
 ns__Object::ns__Object(const char *name)
-{ this->name = (char*)name;
+{
+  this->name = (char*)name;
 }
 
 ns__Object::~ns__Object()
@@ -120,16 +152,19 @@ ns__Object::~ns__Object()
 }
 
 void ns__Object::print()
-{ cout << "Object: " << (name?name:"") << endl;
+{
+  cout << "Object: " << (name?name:"") << endl;
 }
 
 ns__Shape::ns__Shape()
-{ name = (char*)"Shape";
+{
+  name = (char*)"Shape";
   sides = 0;
 }
 
 ns__Shape::ns__Shape(const char *name, int sides)
-{ this->name = (char*)name;
+{
+  this->name = (char*)name;
   this->sides = sides;
 }
 
@@ -138,16 +173,19 @@ ns__Shape::~ns__Shape()
 }
 
 void ns__Shape::print()
-{ cout << "Shape: " << (name?name:"") << " sides=" << sides << endl;
+{
+  cout << "Shape: " << (name?name:"") << " sides=" << sides << endl;
 }
 
 ns__Square::ns__Square()
-{ name = (char*)"Square";
+{
+  name = (char*)"Square";
   ns__Shape::sides = 4;
 }
 
 ns__Square::ns__Square(const char *name, int size)
-{ this->name = (char*)name;
+{
+  this->name = (char*)name;
   this->size = size;
   ns__Shape::sides = 4;
 }
@@ -157,16 +195,19 @@ ns__Square::~ns__Square()
 }
 
 void ns__Square::print()
-{ cout << "Square: " << (name?name:"") << " size=" << size << endl;
+{
+  cout << "Square: " << (name?name:"") << " size=" << size << endl;
 }
 
 ns__List::ns__List()
-{ __ptr = 0;
+{
+  __ptr = 0;
   __size = 0;
 }
 
 ns__List::ns__List(int size)
-{ __ptr = (ns__Object**)malloc(size*sizeof(ns__Object*));
+{
+  __ptr = (ns__Object**)malloc(size*sizeof(ns__Object*));
   __size = size;
 }
 
@@ -175,11 +216,13 @@ ns__List::~ns__List()
 }
 
 ns__Object*& ns__List::operator[](int i)
-{ return __ptr[i];
+{
+  return __ptr[i];
 }
 
 void ns__List::print()
-{ cout << "List: [" << endl;
+{
+  cout << "List: [" << endl;
   for (int i = 0; i < __size; i++)
     __ptr[i]->print();
   cout << "]" << endl;
@@ -188,17 +231,7 @@ void ns__List::print()
 // Web service remote method implementation:
 
 int ns__polytest(struct soap *soap, ns__Object *in, struct ns__polytestResponse &result)
-{ result.out = in;
+{
+  result.out = in;
   return SOAP_OK;
 }
-
-struct Namespace namespaces[] =
-{
-  {"SOAP-ENV", "http://schemas.xmlsoap.org/soap/envelope/", "http://www.w3.org/*/soap-envelope", NULL},
-  {"SOAP-ENC", "http://schemas.xmlsoap.org/soap/encoding/", "http://www.w3.org/*/soap-encoding", NULL},
-  {"xsi", "http://www.w3.org/2000/XMLSchema-instance", "http://www.w3.org/*/XMLSchema-instance", NULL},
-  {"xsd", "http://www.w3.org/2000/XMLSchema", "http://www.w3.org/*/XMLSchema", NULL},
-  {"ns", "urn:copy"},
-  {NULL, NULL}
-};
-
