@@ -1,7 +1,8 @@
 /*
 	calcrest.c
 
-	Example REST calculator service client in C
+	Example REST calculator service + client in C
+        Simple CGI server (can be made stand-alone by adding threading code).
 
 	Compilation in C (see samples/calc/calc.h):
 	$ wsdl2h -R -c calcrest.wsdl
@@ -10,6 +11,7 @@
 	where stdsoap2.c is in the 'gsoap' directory, or use libgsoap:
 	$ cc -o calcrest calcrest.c soapC.c soapClient.c -lgsoap
 
+
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
 Copyright (C) 2001-2013, Robert van Engelen, Genivia, Inc. All Rights Reserved.
@@ -41,8 +43,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "soapH.h"
 #include "calcPOST.nsmap"
 
-const char server[] = "http://websrv.cs.fsu.edu/~engelen/calcrest.cgi";
-/* "http://"; */ /* to test with stdin/out */
+const char server[] = "http://localhost:8080";
 
 int main(int argc, char **argv)
 { struct soap soap;
@@ -50,7 +51,36 @@ int main(int argc, char **argv)
   double out;
   soap_init1(&soap, SOAP_XML_INDENT);
   if (argc < 4)
-    return soap_serve(&soap); /* simple CGI server over stdin/out */
+  {
+    SOAP_SOCKET m, s; /* sockets */
+    if (argc < 2)
+      soap_serve(&soap); /* serve as CGI application */
+    else
+    {
+      m = soap_bind(&soap, NULL, atoi(argv[1]), 1);
+      if (!soap_valid_socket(m))
+      {
+        soap_print_fault(&soap, stderr);
+        exit(1);
+      }
+      fprintf(stderr, "Socket connection successful: master socket = %d\n", m);
+      for ( ; ; )
+      {
+        s = soap_accept(&soap);
+        fprintf(stderr, "Socket connection successful: socket = %d\n", s);
+        if (!soap_valid_socket(s))
+        {
+          soap_print_fault(&soap, stderr);
+          exit(1);
+        } 
+        if (soap_serve(&soap))
+          soap_print_fault(&soap, stderr);
+        soap_destroy(&soap);
+        soap_end(&soap);
+      }
+    }
+    return 0;
+  }
   in.a = strtod(argv[2], NULL);
   in.b = strtod(argv[3], NULL);
   switch (*argv[1])
