@@ -118,6 +118,7 @@ int callback_poll(struct soap *soap, int timeout);
 void *callback_server(void *soap);
 
 void *process_request(void *soap);
+void *callback_server_process_request(void *soap);
 
 int CRYPTO_thread_setup();
 void CRYPTO_thread_cleanup();
@@ -134,7 +135,8 @@ int main(int argc, char **argv)
   soap_register_plugin(soap, soap_wsa);
   soap_register_plugin(soap, soap_wsrm);
   if (argc < 2) /* no args: server */
-  { soap_set_mode(soap, SOAP_IO_KEEPALIVE);
+  {
+    soap_set_mode(soap, SOAP_IO_KEEPALIVE);
 #if !defined(WITH_UDP) && defined(THREADS_H)
     THREAD_TYPE tid;
 #endif
@@ -148,7 +150,8 @@ int main(int argc, char **argv)
 #elif defined(WITH_OPENSSL)
     /* set up SSL locks (not needed for OpenSSL 1.1.0 and greater) */
     if (CRYPTO_thread_setup())
-    { fprintf(stderr, "Cannot setup thread mutex for OpenSSL\n");
+    {
+      fprintf(stderr, "Cannot setup thread mutex for OpenSSL\n");
       exit(1);
     }
     /* WS-Addressing server uses client-side sends, so init SSL for client+server: */
@@ -162,14 +165,16 @@ int main(int argc, char **argv)
       NULL,		/* file with random data to seed randomness */ 
       NULL		/* unique server identification for SSL session cache */
     ))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       exit(1);
     }
 #endif
 
     soap->bind_flags = SO_REUSEADDR;	/* allow immediate port rebinding */
     if (!soap_valid_socket(soap_bind(soap, NULL, serverPort, 100)))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       exit(1);
     }
 
@@ -177,15 +182,18 @@ int main(int argc, char **argv)
 
     soap->accept_timeout = -100000; /* 100ms timeout: do not block on accept */
     for (;;)
-    { /* TCP accept (for UDP simply returns current socket) */
+    {
+      /* TCP accept (for UDP simply returns current socket) */
 #if !defined(WITH_UDP) && defined(THREADS_H)
       struct soap *tsoap;
 #endif
       if (!soap_valid_socket(soap_accept(soap)))
-      { if (soap->errnum)
+      {
+        if (soap->errnum)
           soap_print_fault(soap, stderr);
         else /* timeout, send acknowledgements to all peers */
-	{ soap_wsrm_pulse(soap, -10000); /* 10 ms */
+	{
+          soap_wsrm_pulse(soap, -10000); /* 10 ms */
 #ifdef WITH_UDP
 	  sleep(1); /* optional, needed for UDP: accept() ruturns immediately */
 #endif
@@ -202,7 +210,8 @@ int main(int argc, char **argv)
 #if !defined(WITH_UDP) && defined(WITH_OPENSSL)
       /* SSL accept */
       if (soap_ssl_accept(soap))
-      { soap_print_fault(soap, stderr);
+      {
+        soap_print_fault(soap, stderr);
         fprintf(stderr, "SSL request failed, continue with next call...\n");
         soap_destroy(soap);
         soap_end(soap);
@@ -224,7 +233,8 @@ int main(int argc, char **argv)
     CRYPTO_thread_cleanup();
   }
   else /* client */
-  { xsd__duration expires = 30000; /* 30000 ms to expire */
+  {
+    xsd__duration expires = 30000; /* 30000 ms to expire */
     soap_wsrm_sequence_handle seq;
     struct ns__wsrmdemoResponse res;
     int retry;
@@ -258,7 +268,8 @@ int main(int argc, char **argv)
       NULL,		/* capath to directory with trusted certificates */
       NULL		/* optional file with random data to seed randomness */ 
     ))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       exit(1);
     }
 #endif
@@ -266,14 +277,18 @@ int main(int argc, char **argv)
     /* Command-line options:
        d duplex mode with dual channels
        s callback server for duplex mode (default is callback polling)
+       a enable keep-alive connections
     */
     if (argc >= 3)
-    { if (strchr(argv[2], 's'))
-      { duplex = 1;
+    {
+      if (strchr(argv[2], 's'))
+      {
+        duplex = 1;
         server = 1;
       }
       else if (strchr(argv[2], 'd'))
-      { duplex = 1;
+      {
+        duplex = 1;
 #ifdef WITH_OPENSSL
         fprintf(stderr, "Warning: SSL requires a callback server for duplex mode, because the client waits for the HTTP Accepted response while server is sending a message to the callback: deadlock will occur\n");
 #endif
@@ -286,9 +301,14 @@ int main(int argc, char **argv)
       soap_set_mode(soap, SOAP_IO_KEEPALIVE);
 
     if (duplex)
-    { /* set up the callback for duplex communication */
+    {
+      /* set up the callback for duplex communication */
       replyto = clientURI;
       callback = soap_new1(SOAP_XML_INDENT | SOAP_XML_STRICT);
+      /* enable keep-alive callback server,
+         but this blocks the main server from sending to the client,
+         because the client's callback server does not listen to the port,
+         unless we make the callback server multi-threaded to accept more messages */
       if (alive)
         soap_set_mode(callback, SOAP_IO_KEEPALIVE);
       soap_register_plugin(callback, soap_wsa);
@@ -308,13 +328,15 @@ int main(int argc, char **argv)
         NULL,		/* file with random data to seed randomness */ 
         NULL		/* unique server identification for SSL session cache */
       ))
-      { soap_print_fault(soap, stderr);
+      {
+        soap_print_fault(soap, stderr);
         exit(1);
       }
 #endif
       callback->bind_flags = SO_REUSEADDR;	/* allow immediate port rebinding */
       if (!soap_valid_socket(soap_bind(callback, NULL, clientPort, 100)))
-      { soap_print_fault(soap, stderr);
+      {
+        soap_print_fault(soap, stderr);
         exit(1);
       }
     }
@@ -335,24 +357,29 @@ int main(int argc, char **argv)
 #endif
 
     if (soap_wsrm_create_offer(soap, serverURI, replyto, NULL, expires, DiscardEntireSequence, NULL, &seq))
-    { if (soap->error == 202)
+    {
+      if (soap->error == 202)
         printf("\n**** Create request was accepted\n");
       else if (!duplex) /* if not duplex, error is fatal */
-      { soap_print_fault(soap, stderr);
+      {
+        soap_print_fault(soap, stderr);
         soap_wsrm_seq_free(soap, seq);
         return soap->error;
       }
     }
 
     if (duplex)
-    { for (retry = 10; retry && !soap_wsrm_seq_created(soap, seq); retry--)
-      { if (server)
+    {
+      for (retry = 10; retry && !soap_wsrm_seq_created(soap, seq); retry--)
+      {
+        if (server)
           sleep(1); /* wait for callback server to receive response */
 	else if (callback_poll(callback, 1)) /* poll for 1 sec */
           return callback->error;
       }
       if (!retry)
-      { fprintf(stderr, "CANNOT CREATE SEQUENCE - SERVER NOT RESPONDING\n");
+      {
+        fprintf(stderr, "CANNOT CREATE SEQUENCE - SERVER NOT RESPONDING\n");
         exit(1);
       }
     }
@@ -371,16 +398,20 @@ int main(int argc, char **argv)
     /* this shows how to use a retry loop to improve message delivery */
     /* UDP may timeout when no UDP response message is sent by the server */
     if (soap_wsrm_request(soap, seq, soap_wsa_rand_uuid(soap), RequestAction))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       return soap->error;
     }
     while ((to = soap_wsrm_to(seq)) != NULL && soap_call_ns__wsrmdemo(soap, to, RequestAction, "First Message", &res))
-    { if (soap->error == 202)
-      { printf("\n**** Request was accepted\n");
+    {
+      if (soap->error == 202)
+      {
+        printf("\n**** Request was accepted\n");
         break;
       }
       else if (soap->error == SOAP_NO_TAG) /* empty <Body> */
-      { printf("\n**** Request was accepted, acks received\n");
+      {
+        printf("\n**** Request was accepted, acks received\n");
         break;
       }
       else if (duplex) /* duplex: we opt not to retry (could poll first) */
@@ -400,7 +431,8 @@ int main(int argc, char **argv)
     soap_wsrm_dump(soap, stdout);
 
     if (duplex)
-    { if (server)
+    {
+      if (server)
         sleep(1);
       else if (callback_poll(callback, -200000)) /* poll for 200 ms */
         return callback->error;
@@ -419,12 +451,15 @@ int main(int argc, char **argv)
     /* UDP may timeout when no UDP response message is sent by the server */
     to = soap_wsrm_to(seq);
     if (to)
-    { if (soap_wsrm_request_acks(soap, seq, soap_wsa_rand_uuid(soap), RequestAction))
-      { soap_print_fault(soap, stderr);
+    {
+      if (soap_wsrm_request_acks(soap, seq, soap_wsa_rand_uuid(soap), RequestAction))
+      {
+        soap_print_fault(soap, stderr);
         return soap->error;
       }
       if (soap_call_ns__wsrmdemo(soap, to, RequestAction, (char*)"Second Message", &res))
-      { if (soap->error == 202)
+      {
+        if (soap->error == 202)
           printf("\n**** Request was accepted\n");
         else if (soap->error == SOAP_NO_TAG) /* empty <Body> */
           printf("\n**** Request was accepted, acks received\n");
@@ -435,7 +470,8 @@ int main(int argc, char **argv)
         printf("\n**** Response OK\n");
 
       if (duplex)
-      { if (server)
+      {
+        if (server)
           sleep(1);
         else if (callback_poll(callback, -200000)) /* poll for 200 ms */
           return callback->error;
@@ -443,10 +479,12 @@ int main(int argc, char **argv)
     }
     /* check for any non-acked messages, and resend these */
     if (soap_wsrm_nack(seq))
-    { printf("\n**** Resending "SOAP_ULONG_FORMAT" Non-Acked Messages\n", soap_wsrm_nack(seq));
+    {
+      printf("\n**** Resending "SOAP_ULONG_FORMAT" Non-Acked Messages\n", soap_wsrm_nack(seq));
       soap_wsrm_resend(soap, seq, 0, 0); /* 0 0 means full range of msg nums of non-acked message to resend */
       if (duplex)
-      { if (server)
+      {
+        if (server)
           sleep(1);
         else if (callback_poll(callback, 1)) /* poll for 1 sec */
           return callback->error;
@@ -468,12 +506,15 @@ int main(int argc, char **argv)
     /* UDP may timeout when no UDP response message is sent by the server */
     to = soap_wsrm_to(seq);
     if (to)
-    { if (soap_wsrm_request(soap, seq, soap_wsa_rand_uuid(soap), RequestAction))
-      { soap_print_fault(soap, stderr);
+    {
+      if (soap_wsrm_request(soap, seq, soap_wsa_rand_uuid(soap), RequestAction))
+      {
+        soap_print_fault(soap, stderr);
         return soap->error;
       }
       if (soap_call_ns__wsrmdemo(soap, to, RequestAction, argv[1], &res))
-      { if (soap->error == 202)
+      {
+        if (soap->error == 202)
           printf("\n**** Request was accepted\n");
         else if (soap->error == SOAP_NO_TAG) /* empty <Body> */
           printf("\n**** Request was accepted, acks received\n");
@@ -484,7 +525,8 @@ int main(int argc, char **argv)
         printf("\n**** Response OK\n");
 
       if (duplex)
-      { if (server)
+      {
+        if (server)
           sleep(1); /* allows to get messages before closing */
         else if (callback_poll(callback, -200000)) /* poll for 200 ms */
           return callback->error;
@@ -504,17 +546,20 @@ int main(int argc, char **argv)
 #endif
     /* close the sequence */
     if (soap_wsrm_close(soap, seq, soap_wsa_rand_uuid(soap)))
-    { if (soap->error == 202)
+    {
+      if (soap->error == 202)
         printf("\n**** Close request was accepted\n");
       else if (!duplex)
-      { soap_print_fault(soap, stderr);
+      {
+        soap_print_fault(soap, stderr);
         soap_wsrm_seq_free(soap, seq);
         return soap->error;
       }
     }
 
     if (duplex)
-    { if (server)
+    {
+      if (server)
         sleep(1); /* still accept messages after close */
       else if (callback_poll(callback, 1)) /* poll for 1 sec */
         return callback->error;
@@ -529,7 +574,8 @@ int main(int argc, char **argv)
       soap_wsrm_resend(soap, seq, 0, 0); /* 0 0 means full range of msg nums */
 
       if (duplex)
-      { if (server)
+      {
+        if (server)
           sleep(1);
 	else if (callback_poll(callback, 1)) /* poll for 1 sec */
           return callback->error;
@@ -547,14 +593,16 @@ int main(int argc, char **argv)
 #endif
     /* termination fails if the server did not get all messages */
     if (soap_wsrm_terminate(soap, seq, soap_wsa_rand_uuid(soap)))
-    { if (soap->error == 202)
+    {
+      if (soap->error == 202)
         printf("\n**** Terminate request was accepted\n");
       else if (!duplex || soap->error != SOAP_EOF)
         soap_print_fault(soap, stderr);
     }
 
     if (duplex)
-    { if (server)
+    {
+      if (server)
         sleep(1);
       else if (callback_poll(callback, 1)) /* poll for 1 sec */
         return callback->error;
@@ -572,7 +620,8 @@ int main(int argc, char **argv)
 
     /* delete the callback */
     if (callback)
-    { soap_destroy(callback);
+    {
+      soap_destroy(callback);
       soap_end(callback);
       soap_free(callback);
     }
@@ -601,7 +650,8 @@ void *process_request(void *ctx)
 #if !defined(WITH_UDP) && defined(WITH_OPENSSL)
   /* SSL accept */
   if (soap_ssl_accept(soap))
-  { soap_print_fault(soap, stderr);
+  {
+    soap_print_fault(soap, stderr);
     fprintf(stderr, "SSL request failed\n");
     soap_destroy(soap);
     soap_end(soap);
@@ -614,7 +664,8 @@ void *process_request(void *ctx)
   else if (soap->error == SOAP_EOF && soap->errnum == 0)
     printf("\n**** Thread timed out\n");
   else
-  { printf("\n**** Request served by thread\n");
+  {
+    printf("\n**** Request served by thread\n");
     soap_wsrm_dump(soap, stdout);
   }
   soap_destroy(soap);
@@ -631,6 +682,7 @@ void *process_request(void *ctx)
 \******************************************************************************/
 
 #ifdef THREADS_H
+
 void *callback_server(void *ctx)
 {
   struct soap *soap = (struct soap*)ctx;
@@ -641,27 +693,72 @@ void *callback_server(void *ctx)
 
   printf("\n**** Callback Server Running\n");
 
+  /* run iterative server (keep-alive requires a multi-threaded callback server)  */
   while (soap_valid_socket(soap_accept(soap)))
   {
-#if !defined(WITH_UDP) && defined(WITH_OPENSSL)
-    if (soap_ssl_accept(soap))
-    { soap_print_fault(soap, stderr);
-      fprintf(stderr, "SSL request failed, continue with next call...\n");
-      continue;
+    if (soap->keep_alive)
+    {
+      /* a keep-alive callback server must be multi-threaded, otherwise blocks on open socket */
+      THREAD_TYPE tid;
+      struct soap *tsoap = soap_copy(soap);
+      while (THREAD_CREATE(&tid, (void*(*)(void*))callback_server_process_request, (void*)tsoap))
+        sleep(1);
     }
-#endif
-    if (soap_serve(soap) && soap->error != SOAP_STOP && soap->error != SOAP_EOF)
-      soap_print_fault(soap, stderr);
-    else if (soap->error == SOAP_EOF && !soap->errnum)
-      continue; /* messaging IO timed out */
     else
-      soap_wsrm_dump(soap, stdout);
+    {
+#if !defined(WITH_UDP) && defined(WITH_OPENSSL)
+      if (soap_ssl_accept(soap) != SOAP_OK)
+      {
+        soap_print_fault(soap, stderr);
+        fprintf(stderr, "SSL request failed, continue with next call...\n");
+        continue;
+      }
+#endif
+      /* serve one response at a time */
+      if (soap_serve(soap) && soap->error != SOAP_STOP && soap->error != SOAP_EOF)
+        soap_print_fault(soap, stderr);
+      else if (soap->error == SOAP_EOF && !soap->errnum)
+        continue; /* messaging IO timed out */
+      else
+        soap_wsrm_dump(soap, stdout);
+    }
   }
 
   printf("\n**** Callback Server Terminated\n");
 
   return NULL;
 }
+
+void *callback_server_process_request(void *ctx)
+{
+  struct soap *soap = (struct soap*)ctx;
+
+  THREAD_DETACH(THREAD_ID);
+
+#if !defined(WITH_UDP) && defined(WITH_OPENSSL)
+  if (soap_ssl_accept(soap) != SOAP_OK)
+  {
+    soap_print_fault(soap, stderr);
+    fprintf(stderr, "SSL request failed, continue with next call...\n");
+  }
+  else
+#endif
+  {
+    if (soap_serve(soap) && soap->error != SOAP_STOP && soap->error != SOAP_EOF)
+      soap_print_fault(soap, stderr);
+    else if (soap->error == SOAP_EOF && !soap->errnum)
+      ; /* messaging IO timed out */
+    else
+      soap_wsrm_dump(soap, stdout);
+  }
+
+  soap_destroy(soap);
+  soap_end(soap);
+  soap_free(soap);
+
+  return NULL;
+}
+
 #endif
 
 /******************************************************************************\
@@ -684,13 +781,15 @@ int callback_poll(struct soap *soap, int timeout)
   {
 #if !defined(WITH_UDP) && defined(WITH_OPENSSL)
     if (soap_ssl_accept(soap))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       fprintf(stderr, "SSL request failed, continue with next call...\n");
       continue;
     }
 #endif
     if (soap_serve(soap) && soap->error != SOAP_STOP)
-    { if (soap->error == SOAP_EOF) /* timed out */
+    {
+      if (soap->error == SOAP_EOF) /* timed out */
         return SOAP_OK;
       soap_print_fault(soap, stderr);
       return soap->error;
@@ -711,7 +810,8 @@ int ns__wsrmdemo(struct soap *soap, char *in, struct ns__wsrmdemoResponse *resul
 {
   /* check Basic/Digest Auth, when enabled */
   if (userid && passwd)
-  { if (!soap->userid
+  {
+    if (!soap->userid
      || !soap->passwd
      || strcmp(userid, soap->userid)
      || strcmp(passwd, soap->passwd))
@@ -732,7 +832,8 @@ int ns__wsrmdemo(struct soap *soap, char *in, struct ns__wsrmdemoResponse *resul
   /* simulate a fatal server error, which is possibly relayed */
   /* for fatal errors that terminate the sequence, we must call soap_wsrm_sender_fault() before soap_wsrm_check() */
   if (in && !strcmp(in, "error"))
-  { /* this is fatal, we terminate the sequence */
+  {
+    /* this is fatal, we terminate the sequence */
     int err;
     soap_wsrm_sequence_handle seq = soap_wsrm_seq(soap);
     err = soap_wsrm_error(soap, seq, wsrm__SequenceTerminated);
@@ -743,7 +844,8 @@ int ns__wsrmdemo(struct soap *soap, char *in, struct ns__wsrmdemoResponse *resul
 
   /* simulate a non-fatal user-defined error, which is can be relayed */
   if (in && !strcmp(in, "fault"))
-  { printf("\n**** Simulating Server Operation Fault\n");
+  {
+    printf("\n**** Simulating Server Operation Fault\n");
     return soap_wsrm_sender_fault(soap, "The demo service wsrmdemo() operation returned a fault", NULL);
   }
 
@@ -768,7 +870,8 @@ int ns__wsrmdemoResponse(struct soap *soap, char *out)
 {
   /* check Basic Auth, when enabled */
   if (userid && passwd)
-  { if (!soap->userid
+  {
+    if (!soap->userid
      || !soap->passwd
      || strcmp(userid, soap->userid)
      || strcmp(passwd, soap->passwd))
@@ -801,7 +904,7 @@ int SOAP_ENV__Fault(struct soap *soap,
         char			*Role,			// SOAP 1.2
         struct SOAP_ENV__Detail	*Detail			// SOAP 1.2
 )
-{ 
+{
   soap_send_empty_response(soap, 202); /* HTTP 202 Accepted */
 
   /* populate the fault struct from the operation arguments to print it */
@@ -852,13 +955,15 @@ int SOAP_ENV__Fault(struct soap *soap,
 #if defined(WITH_OPENSSL) && OPENSSL_VERSION_NUMBER < 0x10100000L
 
 struct CRYPTO_dynlock_value
-{ MUTEX_TYPE mutex;
+{
+  MUTEX_TYPE mutex;
 };
 
 static MUTEX_TYPE *mutex_buf;
 
 static struct CRYPTO_dynlock_value *dyn_create_function(const char *file, int line)
-{ struct CRYPTO_dynlock_value *value;
+{
+  struct CRYPTO_dynlock_value *value;
   value = (struct CRYPTO_dynlock_value*)malloc(sizeof(struct CRYPTO_dynlock_value));
   if (value)
     MUTEX_SETUP(value->mutex);
@@ -866,30 +971,35 @@ static struct CRYPTO_dynlock_value *dyn_create_function(const char *file, int li
 }
 
 static void dyn_lock_function(int mode, struct CRYPTO_dynlock_value *l, const char *file, int line)
-{ if (mode & CRYPTO_LOCK)
+{
+  if (mode & CRYPTO_LOCK)
     MUTEX_LOCK(l->mutex);
   else
     MUTEX_UNLOCK(l->mutex);
 }
 
 static void dyn_destroy_function(struct CRYPTO_dynlock_value *l, const char *file, int line)
-{ MUTEX_CLEANUP(l->mutex);
+{
+  MUTEX_CLEANUP(l->mutex);
   free(l);
 }
 
 void locking_function(int mode, int n, const char *file, int line)
-{ if (mode & CRYPTO_LOCK)
+{
+  if (mode & CRYPTO_LOCK)
     MUTEX_LOCK(mutex_buf[n]);
   else
     MUTEX_UNLOCK(mutex_buf[n]);
 }
 
 unsigned long id_function()
-{ return (unsigned long)THREAD_ID;
+{
+  return (unsigned long)THREAD_ID;
 }
 
 int CRYPTO_thread_setup()
-{ int i;
+{
+  int i;
   mutex_buf = (MUTEX_TYPE*)malloc(CRYPTO_num_locks() * sizeof(pthread_mutex_t));
   if (!mutex_buf)
     return SOAP_EOM;
@@ -904,7 +1014,8 @@ int CRYPTO_thread_setup()
 }
 
 void CRYPTO_thread_cleanup()
-{ int i;
+{
+  int i;
   if (!mutex_buf)
     return;
   CRYPTO_set_id_callback(NULL);
@@ -923,7 +1034,8 @@ void CRYPTO_thread_cleanup()
 /* OpenSSL not used or OpenSSL prior to 1.1.0 */
 
 int CRYPTO_thread_setup()
-{ return SOAP_OK;
+{
+  return SOAP_OK;
 }
 
 void CRYPTO_thread_cleanup()
