@@ -9,7 +9,7 @@
 gSOAP XML Web services tools
 Copyright (C) 2000-2012 Robert van Engelen, Genivia Inc., All Rights Reserved.
 This part of the software is released under one of the following licenses:
-GPL, the gSOAP public license, or Genivia's license for commercial use.
+GPL or the gSOAP public license.
 --------------------------------------------------------------------------------
 gSOAP public license.
 
@@ -118,7 +118,12 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 	> ./wsrmdemo hello ds
 	This example shows the main server returning "hello" to the client in
 	duplex mode. The client uses a stand-alone (non-polling) callback
-	server to accept response messages on a port.
+	server to accept response messages on a port. The callback server
+        eventually times out to let the client terminate.
+
+	> ./wsrmdemo hello dsa
+        Same, in duplex mode with client-side multi-threaded callback server
+        keep-alive connections.
 
 	> ./wsrmdemo fault
 	Simulates a fault generated by the server. The fault is non-fatal and
@@ -130,6 +135,10 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 	> ./wsrmdemo fault ds
 	Same, in duplex mode with callback server.
 
+	> ./wsrmdemo fault dsa
+        Same, in duplex mode with client-side multi-threaded callback server
+        keep-alive connections.
+
 	> ./wsrmdemo error
 	Simulates an error generated by the server. The error is fatal and
 	further processing is refused by the server.
@@ -140,6 +149,10 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 	> ./wsrmdemo error ds
 	Same, in duplex mode with callback server.
 
+	> ./wsrmdemo error dsa
+        Same, in duplex mode with client-side multi-threaded callback server
+        keep-alive connections.
+
 	Note 1: when the ReplyTo service is down, the response cannot be
 	relayed and the client (or the fault service when FaultTo is set) will
 	be informed about the failure.
