@@ -6,8 +6,10 @@
 	Prints current time.
 
 	Compile:
-	soapcpp2 -CSL xml-rpc.h
-	c++ json-currentTime.cpp xml-rpc.cpp json.cpp stdsoap2.cpp soapC.cpp
+	$ soapcpp2 -CSL xml-rpc.h
+	$ c++ json-currentTime.cpp xml-rpc.cpp json.cpp stdsoap2.cpp soapC.cpp
+        $ ./json-currentTimeServer 8080 &
+        $ ./json-currentTime
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
@@ -52,7 +54,7 @@ int main()
 
   // make the JSON REST POST request and get response
   request = "getCurrentTime";
-  if (json_call(ctx, "http://www.cs.fsu.edu/~engelen/currentTimeJSON.cgi", request, response))
+  if (json_call(ctx, "http://localhost:8080", request, response))
     soap_print_fault(ctx, stderr);
   else if (response.is_string()) // JSON does not support a dateTime value: this is a string
     cout << "Time = " << response << endl;
