@@ -7,11 +7,12 @@
 	Returns XML-RPC message with current time to client.
 
 	Compile:
-	soapcpp2 xml-rpc.h
-	c++ -o xml-rpc-currentTimeServer xml-rpc-currentTimeServer.cpp xml-rpc.cpp xml-rpc-io.cpp stdsoap2.cpp soapC.cpp
+	$ soapcpp2 xml-rpc.h
+	$ c++ -o xml-rpc-currentTimeServer xml-rpc-currentTimeServer.cpp xml-rpc.cpp xml-rpc-io.cpp stdsoap2.cpp soapC.cpp
 	Install as CGI on Web server
-	Or run as stand-alone server (e.g. on port 18000):
-	./xml-rpc-currentTimeServer 18000
+	Or run as stand-alone server (e.g. on port 8080):
+	$ ./xml-rpc-currentTimeServer 8080 &
+        $ ./xml-rpc-currentTime
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
