@@ -5,9 +5,9 @@
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2001-2008, Robert van Engelen, Genivia Inc. All Rights Reserved.
+Copyright (C) 2000,2024, Robert van Engelen, Genivia Inc. All Rights Reserved.
 This software is released under one of the following licenses:
-GPL or Genivia's license for commercial use.
+GPL.
 --------------------------------------------------------------------------------
 GPL license.
 
@@ -47,26 +47,26 @@ extern int is_builtin_qname(const char*);
 int soap__header::traverse(wsdl__definitions& definitions)
 {
   if (vflag)
-    cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+    std::cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   messageRef = NULL;
   partRef = NULL;
   const char *token = qname_token(message, definitions.targetNamespace);
   if (token)
   {
-    for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
+    for (std::vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
     {
       if ((*message).name && !strcmp((*message).name, token))
       {
 	messageRef = &(*message);
         if (vflag)
-	  cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
+	  std::cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << std::endl;
         break;
       }
     }
   }
   if (!messageRef)
   {
-    for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
+    for (std::vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
     {
       wsdl__definitions *importdefinitions = (*import).definitionsPtr();
       if (importdefinitions)
@@ -74,13 +74,13 @@ int soap__header::traverse(wsdl__definitions& definitions)
 	token = qname_token(message, importdefinitions->targetNamespace);
         if (token)
         {
-	  for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
+	  for (std::vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
           {
 	    if ((*message).name && !strcmp((*message).name, token))
             {
 	      messageRef = &(*message);
               if (vflag)
-	        cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
+	        std::cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << std::endl;
               break;
             }
           }
@@ -92,7 +92,7 @@ int soap__header::traverse(wsdl__definitions& definitions)
   {
     if (part)
     {
-      for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
+      for (std::vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
         if ((*pt).name && !strcmp((*pt).name, part))
 	{
 	  partRef = &(*pt);
@@ -100,11 +100,11 @@ int soap__header::traverse(wsdl__definitions& definitions)
         }
     }
     if (!partRef)
-      cerr << "Warning: soap header has no matching part in message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+      std::cerr << "Warning: soap header has no matching part in message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   }
   else
-    cerr << "Warning: could not find soap header part '" << (part?part:"") << "' message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
-  for (vector<soap__headerfault>::iterator i = headerfault.begin(); i != headerfault.end(); ++i)
+    std::cerr << "Warning: could not find soap header part '" << (part?part:"") << "' message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
+  for (std::vector<soap__headerfault>::iterator i = headerfault.begin(); i != headerfault.end(); ++i)
     (*i).traverse(definitions);
   return SOAP_OK;
 }
@@ -138,26 +138,26 @@ wsdl__part *soap__header::partPtr() const
 int soap__headerfault::traverse(wsdl__definitions& definitions)
 {
   if (vflag)
-    cerr << "    Analyzing soap headerfault in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+    std::cerr << "    Analyzing soap headerfault in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   messageRef = NULL;
   partRef = NULL;
   const char *token = qname_token(message, definitions.targetNamespace);
   if (token)
   {
-    for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
+    for (std::vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
     {
       if ((*message).name && !strcmp((*message).name, token))
       {
 	messageRef = &(*message);
         if (vflag)
-	  cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
+	  std::cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << std::endl;
         break;
       }
     }
   }
   else
   {
-    for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
+    for (std::vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
     {
       wsdl__definitions *importdefinitions = (*import).definitionsPtr();
       if (importdefinitions)
@@ -165,13 +165,13 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
 	token = qname_token(message, importdefinitions->targetNamespace);
         if (token)
         {
-	  for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
+	  for (std::vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
           {
 	    if ((*message).name && !strcmp((*message).name, token))
             {
 	      messageRef = &(*message);
               if (vflag)
-	        cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
+	        std::cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << std::endl;
               break;
             }
           }
@@ -183,7 +183,7 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
   {
     if (part)
     {
-      for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
+      for (std::vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
         if ((*pt).name && !strcmp((*pt).name, part))
 	{
 	  partRef = &(*pt);
@@ -191,10 +191,10 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
         }
     }
     if (!partRef)
-      cerr << "Warning: soap headerfault has no matching part in message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+      std::cerr << "Warning: soap headerfault has no matching part in message '" << (message?message:"") << "' in wsdl definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   }
   else
-    cerr << "Warning: could not find soap headerfault part '" << (part?part:"") << "' message '" << (message?message:"") << "' in wSDL definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+    std::cerr << "Warning: could not find soap headerfault part '" << (part?part:"") << "' message '" << (message?message:"") << "' in wSDL definitions '" << definitions.name << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   return SOAP_OK;
 }
 
@@ -227,25 +227,25 @@ wsdl__part *soap__headerfault::partPtr() const
 int wsoap__header::traverse(wsdl__definitions& definitions)
 {
   if (vflag)
-    cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+    std::cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
   elementRef = NULL;
   // WSDL 2.0
   if (element)
   {
     if (definitions.types)
     {
-      for (vector<xs__schema*>::iterator schema = definitions.types->xs__schema_.begin(); schema != definitions.types->xs__schema_.end(); ++schema)
+      for (std::vector<xs__schema*>::iterator schema = definitions.types->xs__schema_.begin(); schema != definitions.types->xs__schema_.end(); ++schema)
       {
 	const char *token = qname_token(element, (*schema)->targetNamespace);
         if (token)
         {
-	  for (vector<xs__element>::iterator element = (*schema)->element.begin(); element != (*schema)->element.end(); ++element)
+	  for (std::vector<xs__element>::iterator element = (*schema)->element.begin(); element != (*schema)->element.end(); ++element)
           {
 	    if ((*element).name && !strcmp((*element).name, token))
             {
 	      elementRef = &(*element);
               if (vflag)
-                cerr << "   Found soap header element '" << (token?token:"") << "'" << endl;
+                std::cerr << "   Found soap header element '" << (token?token:"") << "'" << std::endl;
               break;
             }
           }
@@ -258,7 +258,7 @@ int wsoap__header::traverse(wsdl__definitions& definitions)
         definitions.builtinElement(element);
       else
         if (!Wflag)
-          cerr << "Warning: no soap header element '" << element << "' in wsdl definitions '" << (definitions.name?definitions.name:"") << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
+          std::cerr << "Warning: no soap header element '" << element << "' in wsdl definitions '" << (definitions.name?definitions.name:"") << "' namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << std::endl;
     }
   }
   return SOAP_OK;
